@@ -103,8 +103,7 @@
   },
 
   # Available backends are: Graphite, Console, File
-  #"backends": [ "Graphite", "Console" ],
-  "backends": [ "Console", "ElasticSearch" ],
+  "backends": [ "Graphite", "Console" ],
 
   # File backend config example
   #"file" : {
@@ -117,8 +116,6 @@
   #  "log" : "/var/tmp/statsd-top.log",
   #},
 
-  "deleteIdleStats" : true,
-
   # statsd will periodically flush its metrics to Graphite
   # Be sure to include the Graphite backend above
   "graphitePort": 2003,
@@ -127,16 +124,6 @@
     "legacyNamespace" : false
   },
 
-  "elasticsearch" : {
-    "host" : "10.20.57.30",
-    "port" : 9200,
-    "path" : "/",
-    "indexPrefix" : "vstatd",
-    "countType" : "vstatd",
-    "timerType" : "vstatd",
-    "timerDataType" : "vstatd",
-  },
-
   ## Repeater backend is not implemented yet
   #"repeater": [ { "host": "10.1.2.3", "port": 8125 } ],
   #"repeaterProtocol": "udp4"
